/********************************************************************************/
/*                                                                              */
/*              bounce_dialog.H                                                 */
/*                                                                              */
/*      Bouncing Balls Demo dialog box header file                              */
/*                                                                              */
/********************************************************************************/


#ifndef BOUNCE_DIALOG_ALREADY_INCLUDED
#define BOUNCE_DIALOG_ALREADY_INCLUDED


#include "bounce_local.H"



/********************************************************************************/
/*                                                                              */
/*      BounceDialogInfo -- generic dialog management                           */
/*                                                                              */
/********************************************************************************/


class BounceDialogInfo : public BaumCallbackInfo {

protected:
   BaumDialog the_dialog;
   BounceManager the_manager;
   Boolean ok_flag;

public:
   BounceDialogInfo(BounceManager);
   virtual ~BounceDialogInfo();

   void activate();
   Bool activateModal();

protected:
   void setup(ConstText,BaumWidget);

private:
   virtual void getContents(ostream&) = 0;

   virtual void setupValues()                                   { }

   virtual void handleApply()                                   { }

   void dialogCallback(BaumDialog&,int);
};




/********************************************************************************/
/*                                                                              */
/*      BounceNumberDialogInfo -- dialog for number of balls                    */
/*                                                                              */
/********************************************************************************/


class BounceNumberDialogInfo : public BounceDialogInfo {

public:
   BounceNumberDialogInfo(BounceManager bm,BaumWidget bw);
   ~BounceNumberDialogInfo();

private:
   void getContents(ostream&);
   void setupValues();

   void handleApply();
};



/********************************************************************************/
/*                                                                              */
/*      BounceVelocityDialogInfo -- dialog for ball velocity                    */
/*                                                                              */
/********************************************************************************/


class BounceVelocityDialogInfo : public BounceDialogInfo {

public:
   BounceVelocityDialogInfo(BounceManager bm,BaumWidget bw);
   ~BounceVelocityDialogInfo();

private:
   void getContents(ostream&);
   void setupValues();

   void handleApply();
};




/********************************************************************************/
/*                                                                              */
/*      BouncePropertyDialogInfo -- dialog for ball properties                  */
/*                                                                              */
/********************************************************************************/


class BouncePropertyDialogInfo : public BounceDialogInfo {

private:
   BounceBall the_ball;
   BaumLayoutList * line_list;

public:
   BouncePropertyDialogInfo(BounceManager bm,BaumWidget bw);
   ~BouncePropertyDialogInfo();

private:
   void getContents(ostream&);
   void setupValues();

   void handleApply();
};




/********************************************************************************/
/*                                                                              */
/*      BounceAboutDialogInfo -- dialog for about information                   */
/*                                                                              */
/********************************************************************************/


class BounceAboutDialogInfo : public BounceDialogInfo {

public:
   BounceAboutDialogInfo(BounceManager bm,BaumWidget bw);
   ~BounceAboutDialogInfo();

private:
   void getContents(ostream&);
};




/********************************************************************************/
/*                                                                              */
/*      BounceSaveFileDialogInfo -- dialog for save/save as file selection      */
/*                                                                              */
/********************************************************************************/


class BounceFileDialogInfo : public BounceDialogInfo {

private:
   StdString what_info;

protected:
   BounceFileDialogInfo(BounceManager bm,ConstText what)
      : BounceDialogInfo(bm)
      { what_info = what; }

private:
   void getContents(ostream&);
   void setupValues();

   void handleApply();
};



class BounceSaveFileDialogInfo : public BounceFileDialogInfo {

public:
   BounceSaveFileDialogInfo(BounceManager bm,BaumWidget bw);
   ~BounceSaveFileDialogInfo();
};




class BounceLoadFileDialogInfo : public BounceFileDialogInfo {

public:
   BounceLoadFileDialogInfo(BounceManager bm,BaumWidget bw);
   ~BounceLoadFileDialogInfo();
};




#endif


/* end of bounce_dialog.H */

