/********************************************************************************/
/*                                                                              */
/*              bounce_local.H                                                  */
/*                                                                              */
/*      Header file definitions for bouncing balls demo program for Baum/Motif  */
/*                                                                              */
/********************************************************************************/


#ifndef BOUNCE_LOCAL_ALREADY_INCLUDED
#define BOUNCE_LOCAL_ALREADY_INCLUDED

#include <baum.H>
#include <baum_widget.H>
#include <baum_window.H>
#include <baum_dialog.H>
#include <baum_menu.H>

#include <stdlib.h>
#include <math.h>

#include <iostream.h>
#include <strstream.h>
#include <fstream.h>
#include <bstring.h>
#include <vector.h>



/********************************************************************************/
/*                                                                              */
/*      Parameters                                                              */
/*                                                                              */
/********************************************************************************/


const   int             ANIM_TIME = 1000/10;
const   int             DEFAULT_NUM_BALLS = 10;
const   double          DEFAULT_RADIUS = 5.0;
const   double          DEFAULT_VELOCITY = 15.0;
const   double          MIN_VELOCITY = 0.5;
const   char * const    BACK_COLOR = "white";
const   char * const    LINE_COLOR = "black";



/********************************************************************************/
/*                                                                              */
/*      Local Types                                                             */
/*                                                                              */
/********************************************************************************/


typedef int             Integer;
typedef double          Coord;
typedef const char *    ConstText;
typedef string          StdString;
typedef char            Character;



/********************************************************************************/
/*                                                                              */
/*      Forward type definitions                                                */
/*                                                                              */
/********************************************************************************/


typedef class BounceAppInfo *           BounceApp;
typedef class BounceWindowInfo *        BounceWindow;
typedef class BounceViewInfo *          BounceView;
typedef class BounceManagerInfo *       BounceManager;
typedef class BounceBallInfo *          BounceBall;
typedef class BounceDrawContextInfo *   BounceDrawContext;

typedef class BounceNumberDialogInfo *          BounceNumberDialog;
typedef class BounceVelocityDialogInfo *        BounceVelocityDialog;
typedef class BouncePropertyDialogInfo *        BouncePropertyDialog;
typedef class BounceAboutDialogInfo *           BounceAboutDialog;
typedef class BounceSaveFileDialogInfo *        BounceSaveFileDialog;
typedef class BounceLoadFileDialogInfo *        BounceLoadFileDialog;

typedef vector<BounceBall>              BounceBallVector;




/********************************************************************************/
/*                                                                              */
/*      Enumeration types                                                       */
/*                                                                              */
/********************************************************************************/


enum BounceShape {
   BOUNCE_SHAPE_CIRCLE,
   BOUNCE_SHAPE_SQUARE,
   BOUNCE_SHAPE_DIAMOND
};



enum BounceType {
   BOUNCE_TYPE_RANDOM,
   BOUNCE_TYPE_TRUE
};



enum BounceColor {
   BOUNCE_COLOR_NONE = 0,

   BOUNCE_COLOR_BLACK = 1,
   BOUNCE_COLOR_RED = 2,
   BOUNCE_COLOR_GREEN = 4,
   BOUNCE_COLOR_YELLOW = 8,
   BOUNCE_COLOR_BLUE = 16,
   BOUNCE_COLOR_CYAN = 32,

   BOUNCE_COLOR_ALL = 63,
   BOUNCE_NUM_COLOR = 6,
   BOUNCE_MAX_COLOR = 64
};



enum BounceLine {
   BOUNCE_LINE_NONE,
   BOUNCE_LINE_SOLID,
   BOUNCE_LINE_THICK_SOLID,
   BOUNCE_LINE_DOTTED,
   BOUNCE_LINE_THICK_DOTTED,

   BOUNCE_LINE_UNDEF
};




#endif


/* end of bounce_local.H */
