/********************************************************************************/
/*                                                                              */
/*              bounceview.cxx                                                  */
/*                                                                              */
/*      Viewing control methods for bouncing balls demo program                 */
/*                                                                              */
/********************************************************************************/


#include "bounce_local.H"

#include "bounce_view.H"
#include "bounce_manager.H"
#include "bounce_context.H"



/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo constructors/destructors                                 */
/*                                                                              */
/********************************************************************************/


BounceViewInfo::BounceViewInfo(BounceManager bm)
{
   draw_context = new BounceDrawContextInfo();
   the_manager = bm;
   x_size = -1;
   y_size = -1;
}




BounceViewInfo::~BounceViewInfo()
{ }




/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo setup methods                                            */
/*                                                                              */
/********************************************************************************/


void
BounceViewInfo::setup(BaumDrawingAreaWidget dw)
{
   the_window = dw;

   dw.exposeCallback(this);
   dw.resizeCallback(this);
   dw.inputCallback(this);
}



/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo callback decoding methods                                */
/*                                                                              */
/********************************************************************************/


void
BounceViewInfo::eventCallback(int reason,XEvent * evt)
{
   switch (reason) {
      case Baum::CR_EXPOSE :
         handleExpose();
         break;
      case Baum::CR_RESIZE :
         handleResize();
         break;
      case Baum::CR_INPUT :
         decodeInput(evt);
         break;
    }
}



void
BounceViewInfo::decodeInput(XEvent * evt)
{
   if (evt->type == ButtonPress) {
      XButtonEvent * btn = &evt->xbutton;
      switch (btn->button) {
         case Button1 :
            handleLeftButton();
            break;
         case Button2 :
            handleMiddleButton();
            break;
         case Button3 :
            handleRightButton();
            break;
       }
    }
   else if (evt->type == KeyPress) {
      XKeyEvent * kevt = &evt->xkey;
      KeySym key = BAUM::lookupKeycode(kevt);
      handleKey(key);
    }
}



/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo drawing callback methods                                 */
/*                                                                              */
/********************************************************************************/


void
BounceViewInfo::handleExpose()
{
   if (x_size < 0) {
      draw_context->setupWindow(the_window);
      getSize();
    }

   redraw();
}



void
BounceViewInfo::handleResize()          
{
   getSize();
   redraw();
}



/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo event callback methods                                   */
/*                                                                              */
/********************************************************************************/


void
BounceViewInfo::handleLeftButton()
{
   the_manager->setNumBalls(the_manager->getNumBalls()+1);
   the_manager->setup();
   nextFrame();
}


void
BounceViewInfo::handleMiddleButton()
{
   Integer ct = the_manager->getNumBalls();

   if (ct > 1) {
      the_manager->setNumBalls(ct-1);
      the_manager->setup();
      redraw();
    }
}


void
BounceViewInfo::handleRightButton()
{
   the_manager->restart();
   nextFrame();
}


void
BounceViewInfo::handleKey(KeySym key)
{
   if (key == 'R' || key == 'r') {
      the_manager->restart();
      nextFrame();
    }
   else if (key == 'N' || key == 'n') {
      nextFrame();
    }
}



/********************************************************************************/
/*                                                                              */
/*      BounceViewInfo drawing methods                                          */
/*                                                                              */
/********************************************************************************/


void
BounceViewInfo::redraw()
{
   the_manager->redraw(draw_context);
}



void
BounceViewInfo::getSize()
{
   x_size = the_window.width();
   y_size = the_window.height();
}




void
BounceViewInfo::nextFrame()
{
   the_manager->nextFrame(draw_context,x_size,y_size);
}




/* end of bouncedraw.cxx */
